package com.ruoyi.mall.mapper;

import java.util.List;
import com.ruoyi.mall.domain.MallSchoolSuggest;
import com.ruoyi.mall.domain.Vo.SchoolSuggestVO;

/**
 * 推荐度Mapper接口
 *
 * @author ruoyi
 * @date 2023-10-28
 */
public interface MallSchoolSuggestMapper
{
    /**
     * 查询推荐度
     *
     * @param suggestId 推荐度主键
     * @return 推荐度
     */
    public MallSchoolSuggest selectMallSchoolSuggestBySuggestId(Long suggestId);

    /**
     * 查询推荐度列表
     *
     * @param mallSchoolSuggest 推荐度
     * @return 推荐度集合
     */
    public List<MallSchoolSuggest> selectMallSchoolSuggestList(MallSchoolSuggest mallSchoolSuggest);

    /**
     * 新增推荐度
     *
     * @param mallSchoolSuggest 推荐度
     * @return 结果
     */
    public int insertMallSchoolSuggest(MallSchoolSuggest mallSchoolSuggest);

    /**
     * 修改推荐度
     *
     * @param mallSchoolSuggest 推荐度
     * @return 结果
     */
    public int updateMallSchoolSuggest(MallSchoolSuggest mallSchoolSuggest);

    /**
     * 删除推荐度
     *
     * @param suggestId 推荐度主键
     * @return 结果
     */
    public int deleteMallSchoolSuggestBySuggestId(Long suggestId);

    /**
     * 批量删除推荐度
     *
     * @param suggestIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMallSchoolSuggestBySuggestIds(Long[] suggestIds);

    /***
     *  推荐度列表
     * @return 结果
     */
    public List<SchoolSuggestVO> selectSuggestList();
}
